@@ -1,12 +1,15 @@
 '''
 | Author:  Ezio416
 | Created: 2022-08-18
-| Updated: 2022-09-26
+| Updated: 2022-10-01
 
 - Functions for various things
 - These are all imported to py416 directly, so just call them like: :func:`py416.timestamp`
 '''
 from datetime import datetime as dt
+from re import findall
+
+from .variables import SEC_D, SEC_H, SEC_M
 
 
 def gettype(thing) -> str:
@@ -41,7 +44,7 @@ def month2num(month_word: str) -> str:
     str
         - zero-padded 2-digit number
     '''
-    if gettype(month_word) != 'str':
+    if type(month_word) is not str:
         raise TypeError(f'input must be a string; invalid: {month_word}')
     month_list = ['january', 'february', 'march', 'april', 'may', 'june', 'july',
                   'august', 'september', 'october', 'november', 'december']
@@ -75,7 +78,7 @@ def secmod(seconds: float, sep: str = '') -> tuple:
         - i.e. ('04d16h47m09s', 9, 47, 16, 4)
     '''
     seconds = abs(int(seconds))
-    if gettype(sep) != 'str':
+    if type(sep) is not str:
         raise ValueError(f'input must be a string; invalid: {sep}')
     if not seconds:
         return ['0s', 0, 0, 0, 0]
@@ -96,6 +99,39 @@ def secmod(seconds: float, sep: str = '') -> tuple:
     return result, s, m, h, d
 
 
+def secmod_inverse(timestr: str) -> int:
+    '''
+    - does essentially the opposite of :func::`secmod`
+    - converts a string to a number of seconds
+
+    Parameters
+    ----------
+    timestr: str
+        - representation of time
+        - must be formatted like the base output from :func::`secmod`, i.e. "3d16h5m47s"
+        - can be missing parts, i.e. "3s47s"
+        - capitalization is ignored
+        - if multiple of the same type of value are passed in the string, i.e. "4h16h", only the first value is grabbed
+
+    Returns
+    -------
+    int
+        - number of seconds
+    '''
+    if type(timestr) is not str:
+        raise TypeError(f'input must be a string; invalid: {timestr}')
+    timestr = timestr.lower()
+    dy = findall(r'[\d]{1,}[d]{1}', timestr)
+    dy = int(dy[0].split('d')[0]) if dy else 0
+    hr = findall(r'[\d]{1,}[h]{1}', timestr)
+    hr = int(hr[0].split('h')[0]) if hr else 0
+    mn = findall(r'[\d]{1,}[m]{1}', timestr)
+    mn = int(mn[0].split('m')[0]) if mn else 0
+    sc = findall(r'[\d]{1,}[s]{1}', timestr)
+    sc = int(sc[0].split('s')[0]) if sc else 0
+    return dy * SEC_D + hr * SEC_H + mn * SEC_M + sc
+
+
 def timestamp(brackets: bool = True, micro: bool = False, offset: bool = True, readable: bool = False, seconds: bool = True, utc: bool = False) -> str:
     '''
     - creates a timestamp in ISO format with additional formatting
@@ -171,12 +207,12 @@ def unpack(iterable) -> tuple:
         - all retrieved items
     `iterable` itself if not a list or tuple
     '''
-    iterables = ('list', 'tuple')
-    if gettype(iterable) not in iterables:
+    iterables = (list, tuple)
+    if type(iterable) not in iterables:
         return iterable
     values = []
     for item in iterable:
-        if gettype(item) not in iterables:
+        if type(item) not in iterables:
             values.append(item)
         else:
             values += list(unpack(item))
